#!/usr/bin/python3
import socket
import time
import picamera
import sys

# global definitions
DEBUG = True
VIDEO_RESOLUTION = (640,480)
VIDEO_FRAMERATE = 20
VIDEO_FORMAT = 'h264'
VIDEO_LENGTH = 60
SERVER_IP = '0.0.0.0'
SERVER_PORT = 10002

# function
def start_video_server(ip,port):
    if DEBUG: print("[MSG]> start video server")
    with picamera.PiCamera() as camera:
        camera.resolution = VIDEO_RESOLUTION
        camera.framerate = VIDEO_FRAMERATE

        server_socket = socket.socket()
        server_socket.setsockopt(socket.SOL_SOCKET,socket.SO_REUSEADDR, 1)
        server_socket.bind((ip,port))
        server_socket.listen(0)

        if DEBUG: print("[MSG]> listening on %s:%d" % (ip, port))
        (client_socket, client_address) = server_socket.accept()

        if DEBUG: print("[MSG]> connection from %s:%d" % (client_address))
        connection = client_socket.makefile('wb')

        try:
            if DEBUG: print("[MSG]> start video capture")
            camera.start_preview()
            time.sleep(1)
            camera.start_recording(connection, format=VIDEO_FORMAT)
            while True:
                camera.wait_recording(VIDEO_LENGTH)
            camera.stop_recording()
            if DEBUG: print("[MSG]> stop video capture")
        except:
            if DEBUG: print("[MSG]> error: exception")
            camera.stop_recording()
            connection.close()
        finally:
            if DEBUG: print("[MSG]> close network socket")
            client_socket.close()
            server_socket.close()

#main
if __name__ == "__main__":
    while 1:
        try:
            start_video_server(SERVER_IP, SERVER_PORT)
        except KeyboardInterrupt:
            if DEBUG: print("[MSG]> Ctrl-C detected ... exiting"); 
            sys.exit()
        except Exception as e:
            if DEBUG: print("[MSG]> error: exception %s" % e)
        time.sleep(1)


